@@ -1,5 +1,6 @@
+#' @importFrom JuliaConnectoR juliaCall
 cocoForecastKStepsJulia <- function(fit, k=3, number_simulations=500, covariates=NULL){
-  dict_out <- JuliaConnectoR::juliaCall("cocoPredictKsteps", fit$julia_reg,k, number_simulations, covariates)
+  dict_out <- JuliaConnectoR::juliaCall("cocoPredictKsteps", fit$julia_reg, k, number_simulations, covariates, fit$link_function)
   return_frequencies <- function(i){as.data.frame(dict_out[[paste0("prediction_", i)]])}
   return(lapply(1:dict_out[["length"]], return_frequencies))
 }
\ No newline at end of file
